@@ -1,9 +1,9 @@
 #ifndef GUARD_processvectors_h
 #define GUARD_processvectors_h
 
-#include "fff.h"
+//#include "fff.h"
 #include "aff.h"
-#include<Rcpp.h>
+//#include<Rcpp.h>
 
 double cpp_computeFFFMean(Rcpp::NumericVector, double);
 
